M = Manifold(4, 'M')
X = M.chart('t x y z') ; t,x,y,z = X[:]
v = M.vector_field((t/8)**2, -t*y/4, t*x/4, t*z/4, name='v')
sphinx_plot(v.plot(ambient_coords=(x, y, z), fixed_coords={t: 1},
                   number_values=4))